==> 0.0.3%2B1.tar.gz: example/lib/src/ui/third/third_page.dart <==
import 'package:example/src/ui/shared/default_button_widget.dart';
import 'package:floative/reactive/element/reactive_element.dart';
import 'package:floative/reactive/element/reactive_element_list.dart';
import 'package:floative/reactive/widgets/reactive_widget.dart';
import 'package:flutter/material.dart';

class ThirdPage extends StatefulWidget {
  @override
  _ThirdPageState createState() => _ThirdPageState();
}

class _ThirdPageState extends State<ThirdPage> {
  ReactiveElement<int> element = ReactiveElement<int>(initialValue: 0);

  ReactiveElementList<int> elementList = ReactiveElementList.fromList([0]);

  ScrollController _scrollController = ScrollController();

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text(
          'Third Page',
          style: TextStyle(color: Colors.black),
        ),
        backgroundColor: Color(0xffE04E68),
        centerTitle: true,
        automaticallyImplyLeading: false,
        elevation: 0,
      ),
      backgroundColor: Color(0xffE04E68),
      body: Container(
        child: Center(
            child: Column(
          children: [
            Reactive(
              element: element,
              builder: (context) {
                return AnimatedContainer(
                  duration: const Duration(milliseconds: 200),
                  margin: EdgeInsets.symmetric(vertical: 20),
                  alignment: Alignment.center,
                  constraints: BoxConstraints(
                    minHeight: element.value % 2 == 0 ? 50 : 60,
                    minWidth: element.value % 2 == 0 ? 90 : 100,
                    maxWidth: element.value % 2 == 0 ? 120 : 150,
                  ),
                  decoration: BoxDecoration(
                      borderRadius: BorderRadius.circular(20),
                      color: Colors.white.withOpacity(0.8)),
                  child: Text(
                    "Current value: ${element.value.toString()}" ?? "",
                    style: TextStyle(
                        color:
                            element.value % 2 == 0 ? Colors.black : Colors.blue,
                        fontWeight: FontWeight.bold),
                    textAlign: TextAlign.center,
                  ),
                );
              },
            ),
            Container(
              decoration: BoxDecoration(
                  color: Colors.white.withOpacity(0.2),
                  borderRadius: BorderRadius.circular(8)),
              margin: EdgeInsets.symmetric(horizontal: 20),
              padding: EdgeInsets.all(4),
              height: 500,
              child: Reactive(
                element: elementList,
                builder: (_) {
                  return ListView(
                    shrinkWrap: true,
                    controller: _scrollController,
                    children: elementList
                        .map((element) => Container(
                              margin: EdgeInsets.symmetric(
                                  vertical: 10, horizontal: 40),
                              height: 30,
                              decoration: BoxDecoration(color: Colors.white),
                              alignment: Alignment.center,
                              child: Text(element.toString()),
                            ))
                        .toList(),
                  );
                },
              ),
            ),
            DefaultButton(
              text: "Increment",
              onTap: () {
                element.change(element.value + 1);
                elementList.add(element.value);
                _scrollController.animateTo(
                    _scrollController.position.maxScrollExtent,
                    duration: const Duration(milliseconds: 200),
                    curve: Curves.bounceIn);
              },
            )
          ],
        )),
      ),
    );
  }

  @override
  void dispose() {
    element.dispose();
    super.dispose();
  }
}

==> 0.0.5%2B1.tar.gz: example/lib/src/ui/third/third_page.dart <==
import 'package:example/src/ui/fourth/fourth_page.dart';
import 'package:example/src/ui/shared/default_button_widget.dart';
import 'package:floative/reactive/element/reactive_element.dart';
import 'package:floative/reactive/element/reactive_list.dart';
import 'package:floative/reactive/widgets/reactive_widget.dart';
import 'package:floative/ship/ship.dart';
import 'package:flutter/material.dart';

class ThirdPage extends StatefulWidget {
  @override
  _ThirdPageState createState() => _ThirdPageState();
}

class _ThirdPageState extends State<ThirdPage> {
  ReactiveElement<int> element = ReactiveElement<int>(initialValue: 0);

  ReactiveList<int> elementList = ReactiveList.fromList([0]);

  ScrollController _scrollController = ScrollController();

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text(
          'Third Page',
          style: TextStyle(color: Colors.black),
        ),
        backgroundColor: Color(0xffE04E68),
        centerTitle: true,
        automaticallyImplyLeading: false,
        elevation: 0,
      ),
      backgroundColor: Color(0xffE04E68),
      body: Container(
        child: Center(
            child: Column(
          children: [
            Reactive(
              element: element,
              builder: (context) {
                return AnimatedContainer(
                  duration: const Duration(milliseconds: 200),
                  margin: EdgeInsets.symmetric(vertical: 20),
                  alignment: Alignment.center,
                  constraints: BoxConstraints(
                    minHeight: element.value % 2 == 0 ? 50 : 60,
                    minWidth: element.value % 2 == 0 ? 90 : 100,
                    maxWidth: element.value % 2 == 0 ? 120 : 150,
                  ),
                  decoration: BoxDecoration(
                      borderRadius: BorderRadius.circular(20),
                      color: Colors.white.withOpacity(0.8)),
                  child: Text(
                    "Current value: ${element.value.toString()}" ?? "",
                    style: TextStyle(
                        color:
                            element.value % 2 == 0 ? Colors.black : Colors.blue,
                        fontWeight: FontWeight.bold),
                    textAlign: TextAlign.center,
                  ),
                );
              },
            ),
            Container(
              decoration: BoxDecoration(
                  color: Colors.white.withOpacity(0.2),
                  borderRadius: BorderRadius.circular(8)),
              margin: EdgeInsets.symmetric(horizontal: 20),
              padding: EdgeInsets.all(4),
              height: 500,
              child: Reactive(
                element: elementList,
                builder: (_) {
                  return ListView(
                    shrinkWrap: true,
                    controller: _scrollController,
                    children: elementList
                        .map((element) => Container(
                              margin: EdgeInsets.symmetric(
                                  vertical: 10, horizontal: 40),
                              height: 30,
                              decoration: BoxDecoration(color: Colors.white),
                              alignment: Alignment.center,
                              child: Text(element.toString()),
                            ))
                        .toList(),
                  );
                },
              ),
            ),
            DefaultButton(
              text: "Increment",
              onTap: () {
                element.value = element.value + 1;
                elementList.add(element.value);
                _scrollController.animateTo(
                    _scrollController.position.maxScrollExtent,
                    duration: const Duration(milliseconds: 200),
                    curve: Curves.bounceIn);
              },
            ),
            DefaultButton(
              text: "Next page",
              onTap: () {
                Ship.I.to(page: FourthPage());
              },
            )
          ],
        )),
      ),
    );
  }

  @override
  void dispose() {
    element.dispose();
    super.dispose();
  }
}
